Welcome to figanos's documentation!
===================================

Figanos: Tool to create **fig**\ ures\  in\  the Our\ **anos**\  style.

Need help?
==========
* Ouranos employees can ask questions on the Ouranos private StackOverflow where you can tag subjects and people. (https://stackoverflow.com/c/ouranos/questions ).
* Potential bugs in figanos can be reported as an issue here: https://github.com/Ouranosinc/figanos/issues .
* Problems with data on Ouranos' servers can be reported as an issue here: https://github.com/Ouranosinc/miranda/issues
* To be aware of changes in figanos, you can "watch" the github repo. You can customize the watch function to notify you of new releases. (https://github.com/Ouranosinc/figanos )

.. toctree::
   :maxdepth: 2
   :caption: Table of Contents:

   installation
   usage
   notebooks/figanos_docs
   notebooks/figanos_colours
   notebooks/figanos_multiplots
   api
   contributing
   authors
   changes

.. toctree::
   :maxdepth: 1
   :caption: All Modules

   apidoc/modules
